.. _release-0-5-0:

0.5.0
=====

Bokeh ``0.5.0`` (Jul 2014) adds the following features:

* Widgets
* Initial AR integration
* bokeh.charts (scatter, bar, histogram)
* improved embedding API
* minor ticks, plot frame, and log axes
